pub(crate) enum Command<S: Server> {
Modify(Box<dyn Modifier<S>>),
Inspect(Box<dyn Inspector<S>>),
Exit,
}Expand description
Commands an App can issue to its runner.
Variants
Modify(Box<dyn Modifier<S>>)
Stop the server, apply the enclosed modification, and, depending on the result restart the server.
Server restarts should be performed sparingly, and may take seconds to minutes (because actix waits for workers to shutdown gracefully.)
Inspect(Box<dyn Inspector<S>>)
Calls the enclosed function on the server
Exit
Stops the server